@@ -72,10 +72,34 @@ class Aws(object):
         return "/".join(seqs)
 
     def send_sns_to(self, arn, message):
+        """
+        final apns_dict = {
+        'aps': {'alert': message, 'badge': 1, 'sound': 'apns_sound.caf'}
+        };
+        final apns_string = jsonEncode(apns_dict);
+        final gcm_dict = {
+        'notification': {'title': 'New message', 'body': message}
+        };
+        final gcm_string = jsonEncode(gcm_dict);
+        final payload = {'default': message, 'APNS_SANDBOX': apns_string, 'APNS': apns_string, 'GCM': gcm_string};
+        final payloadJson = jsonEncode(payload);
+        """
+        apns_dict = {
+            'aps': {'alert': message, 'badge': 1, 'sound': 'apns_sound.caf'}
+        }
+        apns_string = json.dumps(apns_dict)
+        gcm_dict = {
+            'notification': {'title': 'New message', 'body': message}
+        }
+        gcm_string = json.dumps(gcm_dict)
+        payload = {'default': message, 'APNS_SANDBOX': apns_string, 'APNS': apns_string, 'GCM': gcm_string}
+        payloadJson = json.dumps(payload)
+
         try:
             platform_endpoint = self.sns.PlatformEndpoint(arn)
             platform_endpoint.publish(
-                Message=message,
+                Message=payloadJson,
+                MessageStructure='json',
                 Subject='New Broadcast',
             )
         except Exception as e:
