@@ -29,7 +29,8 @@ class Server(object):
         if messages.get('Messages'):
             return {'messages': messages.get('Messages'), 'config': self.config}
         else:
-            logging.info('got no message')
+            #logging.info('got no message')
+            pass
 
 
 class Command(object):
@@ -117,14 +118,20 @@ class Sender(object):
 
 
 class MRequest(object):
-    def __init__(self, raw_message, new_version=False):
+    def __init__(self, raw_message, new_version=False, enc_raw=None):
         self.data = json.loads(raw_message)
         self.new_version = new_version
         self.sender = Sender(self.data.get('sender'))
         self.dispatch = False
+        self.enc_data = enc_raw
         if "zid" in self.data:
+            logging.info('zone messsage:%s' % self.data.get('zid'))
             self.dispatch = True
             self.zone_id = self.data.get('zid')
+        else:
+            logging.info('normal messsage:%s' % self.data.get('zid'))
+            self.dispatch = False
+            self.zone_id = ''
         if "content" in self.data:
             self.message = Message(self.data.get('content'))
         else:
@@ -138,21 +145,17 @@ class MRequest(object):
         return "req user:%s msg:%s" % (self.sender.user_id, self.message)
 
     def dispatch_response(self, target):
-        data = {
-            'zid': self.zone_id,
-            'content': self.message
-        }
-        return Response(data, target)
+        return CastResponse(self.data, target)
 
 
 def send_command_to(config, aws, endpoint, response):
     resp = response.make_response(config, aws)
     logging.info(aws.send_msg(endpoint, resp))
     logging.info('command %s sended', response.data)
-    if isinstance(response, MessageResponse):
+    if isinstance(response, MessageResponse) or isinstance(response, CastResponse):
         # 如果是Message消息就发APNS推送
-        msg = response.data.get('content').get('body').get('content')[:72]
-        resp2 = aws.send_sns_to(response.arn, msg)
+        # msg = response.data.get('content').get('body').get('content')[:72]
+        resp2 = aws.send_sns_to(response.arn, 'You have a new message')
         logging.info('push notification sended:%s with arn:%s', resp2, response.arn)
 
 
@@ -181,8 +184,6 @@ class Response(object):
                     'host_id': 'miaomi',
                     'user_id': config.get('ID'),
                     'nick_name': config.get('NICK'),
-                    #'public_key': config.get('BROKER_PUBLIC'),
-                    #'endpoint': aws.with_url(config.get('ID')),
                     'info': config.get('INFO'),
                     'up_version': "%s" % rd_num
                 }
@@ -194,6 +195,11 @@ class Response(object):
         return self.bin_resp(enced['enc'], str(keypair.publicKey))
 
 
+class CastResponse(Response):
+    def __init__(self, message, target):
+        super(CastResponse, self).__init__(message, target)
+
+
 class MessageResponse(Response):
     def __init__(self, text, target):
         message = {
@@ -208,6 +214,26 @@ class MessageResponse(Response):
         }
         super(MessageResponse, self).__init__(message, target)
 
+    def with_command(self, name, *params):
+        # 加入命令
+        self.data.update({
+            'command': {
+                'name': name,
+                'params': params
+            }
+        })
+
+    def with_multi_command(self, *commands):
+        self.data.update({
+            'pipe': [
+                {
+                    'name': cmd[0],
+                    'params': cmd[1:]
+                }
+                for cmd in commands
+            ]
+        })
+
 
 class BroadCastResponse(Response):
     def __init__(self, text, sender_id, target):
@@ -224,8 +250,6 @@ class BroadCastResponse(Response):
         }
         super(BroadCastResponse, self).__init__(message, target)
 
-
-
 class CommandResponse(Response):
     def __init__(self, name, *params, target=None):
         command = {
@@ -236,6 +260,19 @@ class CommandResponse(Response):
         }
         super(CommandResponse, self).__init__(command, target)
 
+class MultiCommandResponse(Response):
+    def __init__(self, *commands, target=None):
+        command = {
+            'pipe': [
+                {
+                    'name': cmd[0],
+                    'params': cmd[1:]
+                }
+                for cmd in commands
+            ]
+        }
+        super(MultiCommandResponse, self).__init__(command, target)
+
 
 class ContackResponse(Response):
     def __init__(self, users, target):
@@ -249,6 +286,7 @@ class ContackResponse(Response):
                         {
                             'id': user.get('user_id'),
                             'nick_name': user.get('nick_name'),
+                            'cover_type': user.get('cover_type')
                         }
                         for user in users
                     ]
@@ -295,7 +333,7 @@ def process_message(config, message):
         try:
             raw = privateKey.decrypt(publicKey, bytes(bytes_data), None)
             logging.info(f"get message:${raw[:100]}")
-            req = MRequest(raw, new_version=True)
+            req = MRequest(raw, new_version=True, enc_raw=message)
         except Exception as e:
             logging.error(formatError(e))
     return req
@@ -310,13 +348,19 @@ def worker(pid, message):
         req = process_message(config, body)
         aws.rm_msg(config.get('ID'), msg.get('ReceiptHandle'))
         resp = None
-        if req.command:
-            if req.command.name in executors:
-                resp = executors[req.command.name](config, aws, req)
-        if req.message:
-            if req.message.action == "new":
+        try:
+            if req.command:
+                if req.command.name in executors:
+                    resp = executors[req.command.name](config, aws, req)
+            if req.message:
+                if req.message.action == "new":
+                    if MESSAGE_HANDLER in executors:
+                        resp = executors[MESSAGE_HANDLER](config, aws, req)
+            if req.dispatch:
                 if MESSAGE_HANDLER in executors:
                     resp = executors[MESSAGE_HANDLER](config, aws, req)
+        except Exception as e:
+            logging.error(e)
         if resp:
             response_text = resp.make_response(config, aws)
             aws.send_msg(resp.endpoint, response_text)
